@@ -54,8 +54,7 @@ gint keypress (GtkWidget *widget, GdkEventKey *key);
 gint keyrelease (GtkWidget *widget, GdkEventKey *key);
 void switch_focus (GtkNotebook *notebook,
                    GtkNotebookPage *page,
-                   guint page_num,
-                   gpointer user_data);
+                   guint page_num);
 
 static GtkWidget *pfields, *pparty, *pwinlist;
 static GtkWidget *winlistwidget, *partywidget, *fieldswidget;
@@ -100,62 +99,8 @@ static int gtetrinet_poll_func(GPollFD *passed_fds,
 int main (int argc, char *argv[])
 {
     GtkWidget *label;
-    char buf[1024];
     GdkPixbuf *icon_pixbuf;
     GError *err = NULL;
-
-    GTET_STRCPY(buf, "", 4);
-    g_assert(strlen(buf) == 0);
-    g_assert(buf[0] == 0);
-    
-    GTET_STRCAT(buf, "", 4);
-    g_assert(strlen(buf) == 0);
-    g_assert(buf[0] == 0);
-    
-    GTET_STRCPY(buf, "a", 1);
-    g_assert(strlen(buf) == 0);
-    g_assert(buf[0] == 0);
-    
-    GTET_STRCAT(buf, "a", 1);
-    g_assert(strlen(buf) == 0);
-    g_assert(buf[0] == 0);
-    
-    GTET_STRCPY(buf, "abcd", 4);
-    g_assert(strlen(buf) == 3);
-    g_assert(buf[3] == 0);
-    g_assert(buf[2] == 'c');
-    g_assert(buf[1] == 'b');
-    g_assert(buf[0] == 'a');
-    
-    GTET_STRCAT(buf, "xyz", 4);    
-    g_assert(strlen(buf) == 3);
-    g_assert(buf[3] == 0);
-    g_assert(buf[2] == 'c');
-    g_assert(buf[1] == 'b');
-    g_assert(buf[0] == 'a');
-    
-    GTET_STRCAT(buf, "abcd", 7);    
-    g_assert(strlen(buf) == 6);
-    g_assert(buf[6] == 0);
-    g_assert(buf[5] == 'c');
-    g_assert(buf[4] == 'b');
-    g_assert(buf[3] == 'a');
-    g_assert(buf[2] == 'c');
-    g_assert(buf[1] == 'b');
-    g_assert(buf[0] == 'a');
-    
-    GTET_O_STRCPY(buf, "abcd");
-    GTET_O_STRCAT(buf, "abcd");
-    g_assert(strlen(buf) == 8);
-    g_assert(buf[8] == 0);
-    g_assert(buf[7] == 'd');
-    g_assert(buf[6] == 'c');
-    g_assert(buf[5] == 'b');
-    g_assert(buf[4] == 'a');
-    g_assert(buf[3] == 'd');
-    g_assert(buf[2] == 'c');
-    g_assert(buf[1] == 'b');
-    g_assert(buf[0] == 'a');
     
     bindtextdomain(PACKAGE, LOCALEDIR);
     bind_textdomain_codeset(PACKAGE, "UTF-8");
@@ -163,7 +108,6 @@ int main (int argc, char *argv[])
 
     srand (time(NULL));
 
-    //gnome_init_with_popt_table (APPID, APPVERSION, argc, argv, options, 0 , NULL);
     gnome_program_init (APPID, APPVERSION, LIBGNOMEUI_MODULE,
 	                      argc, argv, GNOME_PARAM_POPT_TABLE, options,
 				                GNOME_PARAM_NONE);
@@ -191,49 +135,71 @@ int main (int argc, char *argv[])
     gconf_client_add_dir (gconf_client, "/apps/gtetrinet/keys",
                           GCONF_CLIENT_PRELOAD_ONELEVEL, NULL);
 
+    gconf_client_add_dir (gconf_client, "/apps/gtetrinet/partyline",
+                          GCONF_CLIENT_PRELOAD_ONELEVEL, NULL);
+
     /* Request notification of change for these gconf keys */
     gconf_client_notify_add (gconf_client, "/apps/gtetrinet/sound/midi_player",
-                             sound_midi_player_changed, NULL, NULL, NULL);
+                             (GConfClientNotifyFunc) sound_midi_player_changed,
+			     NULL, NULL, NULL);
                              
     gconf_client_notify_add (gconf_client, "/apps/gtetrinet/sound/enable_sound",
-                             sound_enable_sound_changed, NULL, NULL, NULL);
+                             (GConfClientNotifyFunc) sound_enable_sound_changed,
+			     NULL, NULL, NULL);
                              
     gconf_client_notify_add (gconf_client, "/apps/gtetrinet/sound/enable_midi",
-                             sound_enable_midi_changed, NULL, NULL, NULL);
+                             (GConfClientNotifyFunc) sound_enable_midi_changed,
+			     NULL, NULL, NULL);
                              
     gconf_client_notify_add (gconf_client, "/apps/gtetrinet/themes/theme_dir",
-                             themes_theme_dir_changed, NULL, NULL, NULL);
+                             (GConfClientNotifyFunc) themes_theme_dir_changed,
+			     NULL, NULL, NULL);
 
     gconf_client_notify_add (gconf_client, "/apps/gtetrinet/keys/down",
-                             keys_down_changed, NULL, NULL, NULL);
+                             (GConfClientNotifyFunc) keys_down_changed, NULL, NULL, NULL);
 
     gconf_client_notify_add (gconf_client, "/apps/gtetrinet/keys/left",
-                             keys_left_changed, NULL, NULL, NULL);
+                             (GConfClientNotifyFunc) keys_left_changed,
+			     NULL, NULL, NULL);
 
     gconf_client_notify_add (gconf_client, "/apps/gtetrinet/keys/right",
-                             keys_right_changed, NULL, NULL, NULL);
+                             (GConfClientNotifyFunc) keys_right_changed,
+			     NULL, NULL, NULL);
 
     gconf_client_notify_add (gconf_client, "/apps/gtetrinet/keys/rotate_left",
-                             keys_rotate_left_changed, NULL, NULL, NULL);
+                             (GConfClientNotifyFunc) keys_rotate_left_changed,
+			     NULL, NULL, NULL);
 
     gconf_client_notify_add (gconf_client, "/apps/gtetrinet/keys/rotate_right",
-                             keys_rotate_right_changed, NULL, NULL, NULL);
+                             (GConfClientNotifyFunc) keys_rotate_right_changed,
+			     NULL, NULL, NULL);
 
     gconf_client_notify_add (gconf_client, "/apps/gtetrinet/keys/drop",
-                             keys_drop_changed, NULL, NULL, NULL);
+                             (GConfClientNotifyFunc) keys_drop_changed, NULL,
+			     NULL, NULL);
 
     gconf_client_notify_add (gconf_client, "/apps/gtetrinet/keys/discard",
-                             keys_discard_changed, NULL, NULL, NULL);
+                             (GConfClientNotifyFunc) keys_discard_changed,
+			     NULL, NULL, NULL);
 
     gconf_client_notify_add (gconf_client, "/apps/gtetrinet/keys/message",
-                             keys_message_changed, NULL, NULL, NULL);
+                             (GConfClientNotifyFunc) keys_message_changed,
+			     NULL, NULL, NULL);
+
+    gconf_client_notify_add (gconf_client, "/apps/gtetrinet/partyline/enable_timestamps",
+                             (GConfClientNotifyFunc) partyline_enable_timestamps_changed,
+			     NULL, NULL, NULL);
+    
+    gconf_client_notify_add (gconf_client, "/apps/gtetrinet/partyline/enable_channel_list",
+                             (GConfClientNotifyFunc) partyline_enable_channel_list_changed,
+			     NULL, NULL, NULL);
 
     /* load settings */
     config_loadconfig ();
 
     /* initialise some stuff */
-    client_initpipes ();
     fields_init ();
+    if (!g_thread_supported()) g_thread_init (NULL);
 
     /* first set up the display */
 
@@ -310,6 +276,8 @@ int main (int argc, char *argv[])
 
     gtk_widget_show (notebook);
     g_object_set (G_OBJECT (notebook), "can-focus", FALSE, NULL);
+
+    partyline_show_channel_list (list_enabled);
     gtk_widget_show (app);
 
 //    gtk_widget_set_size_request (partywidget, 480, 360);
@@ -343,10 +311,9 @@ int main (int argc, char *argv[])
     /* gtk_main() */
     gtk_main ();
 
+    client_disconnect ();
     /* cleanup */
-    client_destroypipes ();
     fields_cleanup ();
-    client_connectcancel (); /* kills the client process */
     sound_stopmidi ();
 
     return 0;
@@ -446,7 +413,7 @@ gint keypress (GtkWidget *widget, GdkEventKey *key)
       g_signal_stop_emission_by_name (G_OBJECT(widget), "key-press-event");
     }
 
-    if (game_area && tetrinet_key (key->keyval, key->string))
+    if (game_area && tetrinet_key (key->keyval))
     {
       g_signal_stop_emission_by_name (G_OBJECT(widget), "key-press-event");
       return TRUE;
@@ -610,9 +577,12 @@ void unblock_keyboard_signal (void)
 
 void switch_focus (GtkNotebook *notebook,
                    GtkNotebookPage *page,
-                   guint page_num,
-                   gpointer user_data)
+                   guint page_num)
 {
+
+    notebook = notebook;	/* Suppress compile warnings */
+    page = page;		/* Suppress compile warnings */
+
     if (connected)
       switch (page_num)
       {
